@@ -53,6 +53,7 @@
 #include <QDragEnterEvent>
 #include <QMimeData>
 #include <QStandardItemModel>
+using namespace Qt::Literals::StringLiterals;
 
 using namespace KAlarmCal;
 using namespace KCalendarCore;
@@ -323,7 +324,7 @@ void EditDisplayAlarmDlg::type_initValues(const KAEvent& event)
                 mReminderArchived = true;
             }
         }
-        reminder()->setMinutes(reminderMins, dateOnly());
+        reminder()->setMinutes(reminderMins, isDateOnly());
         reminder()->setOnceOnly(event.reminderOnceOnly());
         reminder()->enableOnceOnly(recurs);
         if (mSpecialActionsButton)
@@ -482,7 +483,7 @@ void EditDisplayAlarmDlg::setAudio(Preferences::SoundType type, const QString& f
 }
 void EditDisplayAlarmDlg::setReminder(int minutes, bool onceOnly)
 {
-    reminder()->setMinutes(minutes, dateOnly());
+    reminder()->setMinutes(minutes, isDateOnly());
     reminder()->setOnceOnly(onceOnly);
     reminder()->enableOnceOnly(isTimedRecurrence());
 }
@@ -862,12 +863,12 @@ void EditCommandAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
     frameLayout->addWidget(mCmdOutputBox);
     auto vlayout = new QVBoxLayout(mCmdOutputBox);
     mCmdOutputGroup = new ButtonGroup(mCmdOutputBox);
-    connect(mCmdOutputGroup, &ButtonGroup::buttonSet, this, &EditCommandAlarmDlg::contentsChanged);
+    connect(mCmdOutputGroup, &ButtonGroup::selectionChanged, this, &EditCommandAlarmDlg::contentsChanged);
 
     // Execute in terminal window
     mCmdExecInTerm = new RadioButton(i18n_radio_ExecInTermWindow(), mCmdOutputBox);
     mCmdExecInTerm->setWhatsThis(i18nc("@info:whatsthis", "Check to execute the command in a terminal window"));
-    mCmdOutputGroup->addButton(mCmdExecInTerm, Preferences::Log_Terminal);
+    mCmdOutputGroup->insertButton(mCmdExecInTerm, Preferences::Log_Terminal);
     vlayout->addWidget(mCmdExecInTerm, 0, Qt::AlignLeft);
 
     // Log file name edit box
@@ -894,14 +895,14 @@ void EditCommandAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
     mCmdLogToFile = new PickLogFileRadio(browseButton, mCmdLogFileEdit, i18nc("@option:radio", "Log to file"), mCmdOutputGroup, mCmdOutputBox);
     mCmdLogToFile->setWhatsThis(i18nc("@info:whatsthis", "Check to log the command output to a local file. The output will be appended to any existing contents of the file."));
     connect(mCmdLogToFile, &PickLogFileRadio::fileChanged, this, &EditCommandAlarmDlg::contentsChanged);
-    mCmdOutputGroup->addButton(mCmdLogToFile, Preferences::Log_File);
+    mCmdOutputGroup->insertButton(mCmdLogToFile, Preferences::Log_File);
     vlayout->addWidget(mCmdLogToFile, 0, Qt::AlignLeft);
     vlayout->addWidget(box);
 
     // Discard output
     mCmdDiscardOutput = new RadioButton(i18nc("@option:radio", "Discard"), mCmdOutputBox);
     mCmdDiscardOutput->setWhatsThis(i18nc("@info:whatsthis", "Check to discard command output."));
-    mCmdOutputGroup->addButton(mCmdDiscardOutput, Preferences::Log_Discard);
+    mCmdOutputGroup->insertButton(mCmdDiscardOutput, Preferences::Log_Discard);
     vlayout->addWidget(mCmdDiscardOutput, 0, Qt::AlignLeft);
 
     // Top-adjust the controls
@@ -1499,13 +1500,13 @@ void EditEmailAlarmDlg::slotTrySuccess()
     disconnect(theApp(), &KAlarmApp::execAlarmSuccess, this, &EditEmailAlarmDlg::slotTrySuccess);
     QString msg;
     QString to = KAEvent::joinEmailAddresses(mEmailAddresses, QStringLiteral("<nl/>"));
-    to.replace(QLatin1Char('<'), QStringLiteral("&lt;"));
-    to.replace(QLatin1Char('>'), QStringLiteral("&gt;"));
+    to.replace('<'_L1, QStringLiteral("&lt;"));
+    to.replace('>'_L1, QStringLiteral("&gt;"));
     if (mEmailBcc->isChecked())
-        msg = QLatin1String("<qt>") + xi18nc("@info", "Email sent to:<nl/>%1<nl/>Bcc: <email>%2</email>",
-                    to, Preferences::emailBccAddress()) + QLatin1String("</qt>");
+        msg = "<qt>"_L1 + xi18nc("@info", "Email sent to:<nl/>%1<nl/>Bcc: <email>%2</email>",
+                    to, Preferences::emailBccAddress()) + "</qt>"_L1;
     else
-        msg = QLatin1String("<qt>") + xi18nc("@info", "Email sent to:<nl/>%1", to) + QLatin1String("</qt>");
+        msg = "<qt>"_L1 + xi18nc("@info", "Email sent to:<nl/>%1", to) + "</qt>"_L1;
     KAMessageBox::information(this, msg);
 }
 
@@ -1522,7 +1523,7 @@ void EditEmailAlarmDlg::openAddressBook()
             return;
         QString addrs = mEmailToEdit->text().trimmed();
         if (!addrs.isEmpty())
-            addrs += QLatin1String(", ");
+            addrs += ", "_L1;
         addrs += person.fullName();
         mEmailToEdit->setText(addrs);
     }
@@ -1884,13 +1885,13 @@ bool CommandEdit::isScript() const
 */
 void CommandEdit::setText(const AlarmText& alarmText)
 {
-    const QString text = alarmText.displayText();
+    const QString newText = alarmText.displayText();
     const bool script = alarmText.isScript();
     mTypeScript->setChecked(script);
     if (script)
-        mScriptEdit->setPlainText(text);
+        mScriptEdit->setPlainText(newText);
     else
-        mCommandEdit->setText(File::pathOrUrl(text));
+        mCommandEdit->setText(File::pathOrUrl(newText));
 }
 
 /******************************************************************************
@@ -1911,7 +1912,7 @@ QString CommandEdit::text(EditAlarmDlg* dlg, bool showErrorMessage) const
         result = mCommandEdit->text().trimmed();
         QString params = result;
         const QString cmd = ShellProcess::splitCommandLine(params);
-        if (cmd.contains(QLatin1Char('=')))
+        if (cmd.contains('='_L1))
         {
             if (showErrorMessage)
                 KAMessageBox::error(dlg, xi18nc("@info", "<para>The command cannot set environment variables:</para><para><icode>%1</icode></para>", cmd));
