@@ -1,7 +1,7 @@
 /*
  *  traywindow.cpp  -  the KDE system tray applet
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2002-2023 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2002-2024 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -22,14 +22,16 @@
 #include "kalarmcalendar/alarmtext.h"
 #include "kalarm_debug.h"
 
+#include <KAboutData>
 #include <KLocalizedString>
 #include <KStandardAction>
-#include <KAboutData>
+#include <KStandardActions>
 
 #include <QList>
 #include <QTimer>
 #include <QLocale>
 #include <QMenu>
+using namespace Qt::Literals::StringLiterals;
 
 #include <stdlib.h>
 #include <limits.h>
@@ -60,38 +62,29 @@ TrayWindow::TrayWindow(MainWindow* parent)
     setStatus(KStatusNotifierItem::Active);
     // Set up the context menu
     mActionEnabled = KAlarm::createAlarmEnableAction(this);
-    addAction(QStringLiteral("tAlarmsEnable"), mActionEnabled);
     contextMenu()->addAction(mActionEnabled);
     connect(theApp(), &KAlarmApp::alarmEnabledToggled, this, &TrayWindow::setEnabledStatus);
     contextMenu()->addSeparator();
 
     mActionNew = new NewAlarmAction(false, i18nc("@action", "New Alarm"), this);
-    addAction(QStringLiteral("tNew"), mActionNew);
     contextMenu()->addAction(mActionNew);
     connect(mActionNew, &NewAlarmAction::selected, this, &TrayWindow::slotNewAlarm);
     connect(mActionNew, &NewAlarmAction::selectedTemplate, this, &TrayWindow::slotNewFromTemplate);
     contextMenu()->addSeparator();
 
     QAction* a = KAlarm::createStopPlayAction(this);
-    addAction(QStringLiteral("tStopPlay"), a);
     contextMenu()->addAction(a);
     QObject::connect(theApp(), &KAlarmApp::audioPlaying, a, &QAction::setVisible);
     QObject::connect(theApp(), &KAlarmApp::audioPlaying, this, &TrayWindow::updateStatus);
 
     a = KAlarm::createSpreadWindowsAction(this);
-    addAction(QStringLiteral("tSpread"), a);
     contextMenu()->addAction(a);
     contextMenu()->addSeparator();
-    contextMenu()->addAction(KStandardAction::preferences(this, &TrayWindow::slotPreferences, this));
+    contextMenu()->addAction(KStandardActions::preferences(this, &TrayWindow::slotPreferences, this));
 
     // Disable standard quit behaviour. We have to intercept the quit event
     // (which triggers KStatusNotifierItem to quit unconditionally).
-    QAction* act = action(QStringLiteral("quit"));
-    if (act)
-    {
-        disconnect(act, &QAction::triggered, this, nullptr);
-        connect(act, &QAction::triggered, this, &TrayWindow::slotQuit);
-    }
+    connect(this, &KStatusNotifierItem::quitRequested, this, &TrayWindow::slotQuit);
 
     // Set icon to correspond with the alarms enabled menu status
     setEnabledStatus(theApp()->alarmsEnabled());
@@ -174,6 +167,7 @@ void TrayWindow::slotPreferences()
 */
 void TrayWindow::slotQuit()
 {
+    abortQuit();    // cancel the default quit action
     // Note: QTimer::singleShot(0, ...) never calls the slot.
     QTimer::singleShot(1, this, &TrayWindow::slotQuitAfter);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
 }
@@ -301,7 +295,7 @@ void TrayWindow::updateToolTip()
     else if (mHaveDisabledAlarms)
     {
         if (!subTitle.isEmpty())
-            subTitle += QLatin1String("<br/>");
+            subTitle += "<br/>"_L1;
         subTitle += i18nc("@info:tooltip Brief: some alarms are disabled", "(Some alarms disabled)");
     }
     setToolTipSubTitle(subTitle);
@@ -338,7 +332,7 @@ QString TrayWindow::tooltipAlarmText() const
     QList<KAEvent> events = KAlarm::getSortedActiveEvents(const_cast<TrayWindow*>(this), &mAlarmsModel);
     for (i = 0, iend = events.count();  i < iend;  ++i)
     {
-        KAEvent* event = &events[i];
+        const KAEvent* event = &events[i];
         if (event->actionSubType() == KAEvent::SubAction::Message)
         {
             TipItem item;
@@ -351,7 +345,7 @@ QString TrayWindow::tooltipAlarmText() const
             if (Preferences::showTooltipAlarmTime())
             {
                 item.text += QLocale().toString(item.dateTime.time(), QLocale::ShortFormat);
-                item.text += QLatin1Char(' ');
+                item.text += ' '_L1;
             }
             if (Preferences::showTooltipTimeToAlarm())
             {
@@ -362,10 +356,10 @@ QString TrayWindow::tooltipAlarmText() const
                 minutes[0] = static_cast<char>((mins%60) / 10 + '0');
                 minutes[1] = static_cast<char>((mins%60) % 10 + '0');
                 if (Preferences::showTooltipAlarmTime())
-                    item.text += i18nc("@info prefix + hours:minutes", "(%1%2:%3)", prefix, mins/60, QLatin1String(minutes));
+                    item.text += i18nc("@info prefix + hours:minutes", "(%1%2:%3)", prefix, mins/60, QLatin1StringView(minutes));
                 else
-                    item.text += i18nc("@info prefix + hours:minutes", "%1%2:%3", prefix, mins/60, QLatin1String(minutes));
-                item.text += QLatin1Char(' ');
+                    item.text += i18nc("@info prefix + hours:minutes", "%1%2:%3", prefix, mins/60, QLatin1StringView(minutes));
+                item.text += ' '_L1;
             }
             item.text += AlarmText::summary(*event);
 
@@ -386,7 +380,7 @@ QString TrayWindow::tooltipAlarmText() const
     {
         qCDebug(KALARM_LOG) << "TrayWindow::tooltipAlarmText: --" << (count+1) << ")" << items.at(i).text;
         if (i > 0)
-            text += QLatin1String("<br />");
+            text += "<br />"_L1;
         text += items.at(i).text;
         if (++count == maxCount)
             break;
